<?php
/**
 * @file
 * Contains \Drupal\kalastatic\Form\KalastaticSettingsForm.
 */

namespace Drupal\kalastatic\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Configure example settings for this site.
 */
class KalastaticSettingsForm extends ConfigFormBase {
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'kalastic_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'kalastatic.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('kalastatic.settings');

    $form = array(
      'kalastatic_build_path' => array(
        '#type' => 'textfield',
        '#title' => $this->t('Build Path'),
        '#default_value' => $config->get('kalastatic_build_path'),
        '#size' => 60,
        '#description' => t("Provide the path to the Kalastatic build folder, relative to the Drupal root. Defaults to the 'build' subfolder of the src path."),
      ),
    );

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $build_path = $form_state->getValue('kalastatic_build_path');

    // Update the config
    $config = \Drupal::service('config.factory')
      ->getEditable('kalastatic.settings');
    $config
      ->set('kalastatic_build_path', $build_path)
      ->save();

    // Automate the configuration of static passthrough.
    kalastatic_update_config($build_path);

    parent::submitForm($form, $form_state);
  }
}
